@@ -38,11 +38,13 @@ int main(int argc, char* argv[])
     }
 
     in  = fopen(argv[1], "rb");
+    if (!in) {
+        perror("ERROR: unable to open input file");
+        return 1;
+    }
     out = fopen(argv[2], "wb");
-
-    if (!in || !out) {
-        perror("ERROR: unable to open files");
-        fclose(out);
+    if (!out) {
+        perror("ERROR: unable to open output file");
         fclose(in);
         return 1;
     }
@@ -56,8 +58,8 @@ int main(int argc, char* argv[])
             return 1;
         }
 
-        /* This is the place where you may wish to modify the clone */
-        /* E.g.
+        /* this is the place where you may wish to modify the clone */
+        /* e.g.
            CODES_CHECK(codes_set_long(clone_handle, "centre", 250),0);
            etc...
          */
